# Useful Resources

For more information about SuperCollider, check out the following links:

- [SuperCollider website](https://supercollider.github.io/)
- [SuperCollider on GitHub](https://github.com/supercollider/supercollider)


- [SuperCollider documentation and help](https://doc.sccode.org/)
  - [Client vs Server](https://doc.sccode.org/Guides/ClientVsServer.html)
  - [Server Architecture - Main Design Concepts](https://doc.sccode.org/Reference/Server-Architecture.html)
  - [Server Command Reference](https://doc.sccode.org/Reference/Server-Command-Reference.html)
  - [Server Guide](https://doc.sccode.org/Guides/Server-Guide.html)
  - [Multi-client Setups](https://doc.sccode.org/Guides/MultiClient_Setups.html)
  - [OSC Communication](https://doc.sccode.org/Guides/OSC_communication.html)


- SuperCollider Language
   - [sclang Startup File](https://doc.sccode.org/Reference/StartupFile.html)
   - [Symbolic Notations](https://doc.sccode.org/Overviews/SymbolicNotations.html)
   - [Operators](https://doc.sccode.org/Overviews/Operators.html)
   - [Syntax Shortcuts](https://doc.sccode.org/Reference/Syntax-Shortcuts.html)
